@@ -26,7 +26,9 @@
 */
 
 #include <cstring>  // for std::strcmp
+#include <exception>
 #include <iostream> // for std::cout, std::cerr
+#include <vector>
 
 // For assembling multipolygons
 #include <osmium/area/assembler.hpp>
@@ -81,6 +83,8 @@ public:
 
 }; // class WKTDump
 
+namespace {
+
 void print_help() {
     std::cout << "osmium_area_test [OPTIONS] OSMFILE\n\n"
               << "Read OSMFILE and build multipolygons from it.\n"
@@ -94,6 +98,8 @@ void print_usage(const char* prgname) {
     std::cerr << "Usage: " << prgname << " [OPTIONS] OSMFILE\n";
 }
 
+} // anonymous namespace
+
 int main(int argc, char* argv[]) {
     if (argc > 1 && (!std::strcmp(argv[1], "-h") ||
                      !std::strcmp(argv[1], "--help"))) {
